@@ -27,6 +27,9 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
+#define BASE_FORMAT "/tmp/scrollkeeper-%s"
+#define FNAME_FORMAT BASE_FORMAT "/contents.%d"
+
 static int id = 0;
 
 void print_usage(char *proc_name) {
@@ -148,7 +151,6 @@ void process_node(TiXmlNode *pParent) {
 char *find_dump_name() {
     char *filename = NULL;
     const char *user = getenv("USERNAME");
-    char *basepath = NULL;
     int last = 0;
     unsigned int lasttime = 0;
     int init = 1;
@@ -158,17 +160,14 @@ char *find_dump_name() {
         user = "UNKNOWN";
     }
 
-    basepath = (char *)malloc(sizeof(char) *
-                              (strlen(user) + 18 /*/tmp/scrollkeeper.*/ + 1));
-    sprintf(basepath, "/tmp/scrollkeeper-%s", user);
-    mkdir(basepath, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
-
-    filename = (char *)malloc(sizeof(char) *
-                              (strlen(basepath) + 10 /*contents.0*/ + 1));
+    filename =
+        (char *)malloc(sizeof(char) * (sizeof(FNAME_FORMAT) + strlen(user)));
+    sprintf(filename, BASE_FORMAT, user);
+    mkdir(filename, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
 
     for (int i = 0; i < 5; i++) {
         struct stat sbuf;
-        sprintf(filename, "%s/contents.%d", basepath, i);
+        sprintf(filename, FNAME_FORMAT, user, i);
         if (stat(filename, &sbuf) == -1) {
             last = i;
             break;
@@ -179,8 +178,7 @@ char *find_dump_name() {
             lasttime = sbuf.st_mtime;
         }
     }
-    sprintf(filename, "%s/contents.%d", basepath, last);
-    free(basepath);
+    sprintf(filename, FNAME_FORMAT, user, last);
 
     return filename;
 }
